MethodChannelAclScoring class

An implementation of AclScoringPlatform that uses method channels.

Inheritance

Constructors

MethodChannelAclScoring()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
getPlatformVersion
override
handleFCMMessage(Map<String, dynamic> data) → Future<bool>
Handle FCM message function
override
initialize(Map<String, dynamic> config) → Future<bool>
Initialize service
override
isAppUsageAllowed() → Future<bool>
Android only
override
isBindNotificationListenerAllowed() → Future<bool>
Android only
override
loadDeviceRisks() → Future<bool>
Load device risks
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAppUsageSetting() → Future<void>
Android only
override
openBindNotificationSetting() → Future<void>
Android only
override
registerDevice() → Future<String?>
Register device
override
startMonitoring() → Future<bool>
Start mornitoring
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited